@@ -41,7 +41,6 @@ import org.apache.commons.logging.LogFactory;
  * Miscellaneous utility methods for configurations.
  *
  * @see ConfigurationConverter Utility methods to convert configurations.
- *
  */
 public final class ConfigurationUtils {
     /** Constant for the name of the clone() method. */
@@ -139,7 +138,7 @@ public final class ConfigurationUtils {
     }
 
     /**
-     * Get a string representation of the key/value mappings of a configuration.
+     * Gets a string representation of the key/value mappings of a configuration.
      *
      * @param configuration the configuration
      * @return a string representation of the configuration
@@ -152,7 +151,7 @@ public final class ConfigurationUtils {
     }
 
     /**
-     * Get a string representation of the key/value mappings of a configuration. This version of the method exists only for
+     * Gets a string representation of the key/value mappings of a configuration. This version of the method exists only for
      * backwards compatibility reason.
      *
      * @param configuration the configuration
@@ -178,10 +177,7 @@ public final class ConfigurationUtils {
      * @since 2.2
      */
     public static void copy(final ImmutableConfiguration source, final Configuration target) {
-        for (final Iterator<String> keys = source.getKeys(); keys.hasNext();) {
-            final String key = keys.next();
-            target.setProperty(key, source.getProperty(key));
-        }
+        source.getKeys().forEachRemaining(key -> target.setProperty(key, source.getProperty(key)));
     }
 
     /**
@@ -219,10 +215,7 @@ public final class ConfigurationUtils {
      * @since 2.2
      */
     public static void append(final ImmutableConfiguration source, final Configuration target) {
-        for (final Iterator<String> keys = source.getKeys(); keys.hasNext();) {
-            final String key = keys.next();
-            target.addProperty(key, source.getProperty(key));
-        }
+        source.getKeys().forEachRemaining(key -> target.addProperty(key, source.getProperty(key)));
     }
 
     /**
@@ -384,7 +377,7 @@ public final class ConfigurationUtils {
         }
 
         try {
-            return sync.getClass().newInstance();
+            return sync.getClass().getConstructor().newInstance();
         } catch (final Exception ex) {
             LOG.info("Cannot create new instance of " + sync.getClass());
         }
