@@ -61,7 +61,7 @@ public class HierarchicalConfigurationXMLReader<T> extends ConfigurationXMLReade
     }
 
     /**
-     * Returns the configuration object to be parsed.
+     * Gets the configuration object to be parsed.
      *
      * @return the configuration object to be parsed
      */
@@ -79,7 +79,7 @@ public class HierarchicalConfigurationXMLReader<T> extends ConfigurationXMLReade
     }
 
     /**
-     * Returns the configuration object to be processed.
+     * Gets the configuration object to be processed.
      *
      * @return the actual configuration object
      */
@@ -100,7 +100,7 @@ public class HierarchicalConfigurationXMLReader<T> extends ConfigurationXMLReade
     /**
      * A specialized visitor class for generating SAX events for a hierarchical node structure.
      */
-    private class SAXVisitor extends ConfigurationNodeVisitorAdapter<T> {
+    private final class SAXVisitor extends ConfigurationNodeVisitorAdapter<T> {
         /** Constant for the attribute type. */
         private static final String ATTR_TYPE = "CDATA";
 
@@ -151,12 +151,12 @@ public class HierarchicalConfigurationXMLReader<T> extends ConfigurationXMLReade
         protected Attributes fetchAttributes(final T node, final NodeHandler<T> handler) {
             final AttributesImpl attrs = new AttributesImpl();
 
-            for (final String attr : handler.getAttributes(node)) {
+            handler.getAttributes(node).forEach(attr -> {
                 final Object value = handler.getAttributeValue(node, attr);
                 if (value != null) {
                     attrs.addAttribute(NS_URI, attr, attr, ATTR_TYPE, value.toString());
                 }
-            }
+            });
 
             return attrs;
         }
