@@ -63,7 +63,7 @@ public final class EventListenerRegistrationData<T extends Event> {
     }
 
     /**
-     * Returns the event type for this listener registration.
+     * Gets the event type for this listener registration.
      *
      * @return the event type
      */
@@ -72,7 +72,7 @@ public final class EventListenerRegistrationData<T extends Event> {
     }
 
     /**
-     * Returns the listener this registration is about.
+     * Gets the listener this registration is about.
      *
      * @return the event listener
      */
@@ -82,9 +82,8 @@ public final class EventListenerRegistrationData<T extends Event> {
 
     @Override
     public int hashCode() {
-        int result = eventType.hashCode();
-        result = HASH_FACTOR * result + listener.hashCode();
-        return result;
+        final int result = eventType.hashCode();
+        return HASH_FACTOR * result + listener.hashCode();
     }
 
     /**
